/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2009-2010 EBM WebSourcing - http://www.petalslink.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

package org.ow2.petals.se.quartz.job;

import java.util.logging.Level;
import java.util.logging.Logger;

import javax.jbi.messaging.MessagingException;

import org.ow2.petals.component.framework.api.Message.MEPConstants;
import org.ow2.petals.component.framework.api.configuration.ConfigurationExtensions;
import org.ow2.petals.component.framework.api.exception.PEtALSCDKException;
import org.ow2.petals.component.framework.api.message.Exchange;
import org.ow2.petals.component.framework.jbidescriptor.generated.Consumes;
import org.ow2.petals.component.framework.util.UtilFactory;
import org.ow2.petals.se.quartz.QuartzExternalListener;
import org.ow2.petals.se.quartz.utils.QuartzConstants;
import org.ow2.petals.se.quartz.utils.QuartzUtils;
import org.quartz.Job;
import org.quartz.JobDataMap;
import org.quartz.JobExecutionContext;
import org.quartz.JobExecutionException;

/**
 * @author Adrien LOUIS - EBM WebSourcing
 */
public class EmitSignalJob implements Job {

	/*
	 * (non-Javadoc)
	 * @see org.quartz.Job
	 * #execute(org.quartz.JobExecutionContext)
	 */
	public void execute( JobExecutionContext jobContext ) throws JobExecutionException {

		// Get the external listener and the information it contains
		JobDataMap dataMap = jobContext.getJobDetail().getJobDataMap();
		QuartzExternalListener quartzExternalListener = (QuartzExternalListener) dataMap.get(QuartzConstants.SCHEDULER_MANAGER);
		Consumes consume = quartzExternalListener.getConsumes();
		ConfigurationExtensions extensions = new ConfigurationExtensions( consume.getAny());
		Logger logger = quartzExternalListener.getLogger();

		// Invoke the service
		String serviceIdentifier = QuartzUtils.buildTargetServiceIdentifier( consume );
		try {
			Exchange exchange = quartzExternalListener.createConsumeExchange( consume, MEPConstants.IN_ONLY_PATTERN );
			String content = extensions.get( QuartzConstants.CONTENT_EXPRESSION );
			if( content != null )
				content = content.trim();

			if( logger.isLoggable( Level.FINE )) {
				String msg =
					"Creating the scheduled message " + exchange.getExchangeId()
					+ " for " +  serviceIdentifier + ".";
				logger.fine( msg );
			}

			if( logger.isLoggable( Level.FINEST ))
				logger.finest( exchange.getExchangeId() + ": the sent content is\n" + content );

			exchange.getInMessage().setContent( UtilFactory.getSourceUtil().createSource( content ));
			quartzExternalListener.send( exchange );

			if( logger.isLoggable( Level.INFO )) {
				String msg = "The scheduled message " + exchange.getExchangeId() + " was successfully sent to " +  serviceIdentifier + ".";
				logger.info( msg );
			}

		} catch( final MessagingException e ) {
			if( logger.isLoggable( Level.INFO ))
				logger.info( "A scheduled message cound not be sent to " + serviceIdentifier + " (MessagingException)." );

		} catch( final PEtALSCDKException e ) {
			if( logger.isLoggable( Level.INFO ))
				logger.info( "A scheduled message cound not be sent to " + serviceIdentifier + " (PEtALSCDKException)." );
		}
	}
}
